# -*- coding: utf-8 -*-
html_use_modindex = False
html_use_index = False

source_suffix = '.rst'
master_doc = 'index'

project = u'Sphinx htmlslide sample'
copyright = u'2011, Sphinx-users.jp'

################################################################
# Extension and Theme setting
# You need to install `easy_install sphinxjp.themes.sphinxjp`

extensions = ['sphinxjp.themecore']
html_theme = 'htmlslide'

################################################################
# syntax highlighting style
pygments_style = 'monokai'





# -*- coding: utf-8 -*-

from os import path

package_dir = path.abspath(path.dirname(__file__))
template_path = path.join(package_dir, 'templates')


#def get_path():
#    """entry-point for sphinxjp.themecore theme."""
#    return template_path



# -*- coding: utf-8 -*-
from setuptools import setup, find_packages
import os, sys

version = '0.1.1'
long_description = '\n'.join([
        open(os.path.join("src","README.txt")).read(),
        open(os.path.join("src","AUTHORS.txt")).read(),
        open(os.path.join("src","TODOS.txt")).read(),
        open(os.path.join("src","HISTORY.txt")).read(),
        ])

classifiers = [
    "Development Status :: 4 - Beta",
    "License :: OSI Approved :: MIT License",
    "Programming Language :: Python",
    "Topic :: Software Development",
    "Topic :: Software Development :: Documentation",
    "Topic :: Text Processing :: Markup",
]

setup(
     name='sphinxjp.themes.htmlslide',
     version=version,
     description='A sphinx theme for generate HTML Slide presentation.',
     long_description=long_description,
     classifiers=classifiers,
     keywords=['sphinx', 'reStructuredText', 'presentation'],
     author='Takayuki SHIMIZUKAWA',
     author_email='shimizukawa at gmail dot com',
     url='http://bitbucket.org/shimizukawa/sphinxjp.themes.htmlslide',
     license='MIT',
     packages=find_packages('src'),
     package_dir={'': 'src'},
     package_data = {'': ['buildout.cfg']},
     include_package_data=True,
     install_requires=[
        'setuptools',
        'docutils',
        'sphinx',
        'sphinxjp.themecore',
     ],
     entry_points="""
        [sphinx_themes]
        path = sphinxjp.themes.htmlslide:template_path
     """,
     zip_safe=False,
)

